package org.apache.bcel.classfile;

import java.io.DataInput;
import java.io.DataOutputStream;
import java.io.IOException;

public final class ModuleProvides implements Cloneable, Node {
   private final int providesIndex;
   private final int providesWithCount;
   private final int[] providesWithIndex;

   ModuleProvides(DataInput file) throws IOException {
      this.providesIndex = file.readUnsignedShort();
      this.providesWithCount = file.readUnsignedShort();
      this.providesWithIndex = new int[this.providesWithCount];

      for(int i = 0; i < this.providesWithCount; ++i) {
         this.providesWithIndex[i] = file.readUnsignedShort();
      }

   }

   public void accept(Visitor v) {
      v.visitModuleProvides(this);
   }

   public ModuleProvides copy() {
      try {
         return (ModuleProvides)this.clone();
      } catch (CloneNotSupportedException var2) {
         return null;
      }
   }

   public void dump(DataOutputStream file) throws IOException {
      file.writeShort(this.providesIndex);
      file.writeShort(this.providesWithCount);
      int[] var2 = this.providesWithIndex;
      int var3 = var2.length;

      for(int var4 = 0; var4 < var3; ++var4) {
         int entry = var2[var4];
         file.writeShort(entry);
      }

   }

   public String toString() {
      return "provides(" + this.providesIndex + ", " + this.providesWithCount + ", ...)";
   }

   public String toString(ConstantPool constantPool) {
      StringBuilder buf = new StringBuilder();
      String interfaceName = constantPool.constantToString(this.providesIndex, (byte)7);
      buf.append(Utility.compactClassName(interfaceName, false));
      buf.append(", with(").append(this.providesWithCount).append("):\n");
      int[] var4 = this.providesWithIndex;
      int var5 = var4.length;

      for(int var6 = 0; var6 < var5; ++var6) {
         int index = var4[var6];
         String className = constantPool.getConstantString(index, (byte)7);
         buf.append("      ").append(Utility.compactClassName(className, false)).append("\n");
      }

      return buf.substring(0, buf.length() - 1);
   }
}
